@@ -26,7 +26,8 @@ class Puppet::Provider::Trove < Puppet::Provider
   end
 
   def self.get_trove_credentials
-    auth_keys = ['auth_uri', 'project_name', 'username', 'password']
+    auth_keys = ['auth_uri', 'project_name', 'username', 'password',
+                 'project_domain_name', 'user_domain_name']
     conf = trove_conf
     if conf and conf['keystone_authtoken'] and
         auth_keys.all?{|k| !conf['keystone_authtoken'][k].nil?}
@@ -53,10 +54,12 @@ correctly configured.")
   def self.auth_trove(*args)
     q = trove_credentials
     authenv = {
-      :OS_AUTH_URL    => q['auth_uri'],
-      :OS_USERNAME    => q['username'],
-      :OS_PROJECT_NAME => q['project_name'],
-      :OS_PASSWORD    => q['password']
+      :OS_AUTH_URL            => q['auth_uri'],
+      :OS_USERNAME            => q['username'],
+      :OS_PROJECT_NAME        => q['project_name'],
+      :OS_PASSWORD            => q['password'],
+      :OS_PROJECT_DOMAIN_NAME => q['project_domain_name'],
+      :OS_USER_DOMAIN_NAME    => q['user_domain_name']
     }
     begin
       withenv authenv do
